{% load dwll %}
<footer class="py-5 bg-dark">
  <div class="container">
    <p class="m-0 text-center text-white">
      {% display_message 'footer.copyright' 'Copyright' %} &copy; 
      {% display_message 'footer.copyright.year' 'Tu Página Web 2022' %}
    </p>
    <p class="m-0 text-center text-white">
      <!-- Please do not remove the next information -->
      <small>Page based on DWLL</small>
    </p>
  </div>
</footer>
<!-- Bootstrap core JS-->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>