# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2020-06-11 22:45
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Configuration',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('1', 'Activo'), ('2', 'Inactivo')], default='1', max_length=1)),
                ('creation_user', models.CharField(blank=True, max_length=64, null=True)),
                ('modification_user', models.CharField(blank=True, max_length=64, null=True)),
                ('creation_date', models.DateTimeField(blank=True, null=True)),
                ('modification_date', models.DateTimeField(blank=True, null=True)),
                ('name', models.CharField(max_length=50)),
                ('value', models.CharField(blank=True, max_length=350, null=True)),
                ('description', models.CharField(blank=True, max_length=200, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Language',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('1', 'Activo'), ('2', 'Inactivo')], default='1', max_length=1)),
                ('creation_user', models.CharField(blank=True, max_length=64, null=True)),
                ('modification_user', models.CharField(blank=True, max_length=64, null=True)),
                ('creation_date', models.DateTimeField(blank=True, null=True)),
                ('modification_date', models.DateTimeField(blank=True, null=True)),
                ('name', models.CharField(blank=True, max_length=16, null=True, unique=True)),
                ('title', models.CharField(blank=True, max_length=32, null=True, unique=True)),
                ('i18n', models.CharField(blank=True, max_length=5, null=True)),
                ('default', models.BooleanField(default=False)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Message',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('1', 'Activo'), ('2', 'Inactivo')], default='1', max_length=1)),
                ('creation_user', models.CharField(blank=True, max_length=64, null=True)),
                ('modification_user', models.CharField(blank=True, max_length=64, null=True)),
                ('creation_date', models.DateTimeField(blank=True, null=True)),
                ('modification_date', models.DateTimeField(blank=True, null=True)),
                ('name', models.CharField(blank=True, max_length=100, null=True, unique=True)),
                ('text', models.TextField(blank=True, null=True)),
                ('published', models.BooleanField(default=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MessageTraduction',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('1', 'Activo'), ('2', 'Inactivo')], default='1', max_length=1)),
                ('creation_user', models.CharField(blank=True, max_length=64, null=True)),
                ('modification_user', models.CharField(blank=True, max_length=64, null=True)),
                ('creation_date', models.DateTimeField(blank=True, null=True)),
                ('modification_date', models.DateTimeField(blank=True, null=True)),
                ('text', models.TextField(blank=True, null=True)),
                ('language', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='dwll.Language')),
                ('message', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='dwll.Message')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
