{% extends 'base.html' %}
{% load i18n %}
{% load dwll %}
{% block title %}{% display_message 'save.title' 'Salvar Registro' %}{% endblock %}
{% block body %}
<section class="py-5">
    <div class="container my-5">
        <h1>{% display_message 'save.title' 'Salvar Registro' %}</h1>
        <div class="row">
            <div class="col-md-12">
                <form id="this_form" action="" method="post" mode="normal" enctype="multipart/form-data">
                    {% csrf_token %}
                    <div class="row">
                        <div class="col-md-6 form-group">
                            <label>{% display_message 'form.slug' 'Slug' %}:</label> {{form.slug}}
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-6 form-group">
                            <label>{% display_message 'form.name' 'Nombre' %}:</label> {{form.name}}                        
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-6">
                            <br>
                            <button type="submit" form="this_form" class="btn btn-primary">
                                {% display_message 'form.save' 'Guardar' %}
                            </button>
                            <a href="{% url '[ITEM]s' %}" class="btn btn-secondary">
                                {% display_message 'form.cancel' 'Cancelar' %}
                            </a>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</section>
{% endblock %}