<!DOCTYPE html>
{% load i18n %}
{% load dwll %}
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta content="width=device-width, initial-scale=1.0" name="viewport">
    <title>{% block title %}{% display_message 'home.title' %}{% endblock %}</title>
    {% block metatags %}
    <meta content="{% get_configuration 'META_DESCRIPTION' %}" name="description">
    <meta content="{% get_configuration 'META_KEYWORDS' %}" name="keywords">
    {% endblock %}
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css?family=Open+Sans:300,300i,400,400i,600,600i,700,700i|Raleway:300,300i,400,400i,500,500i,600,600i,700,700i|Poppins:300,300i,400,400i,500,500i,600,600i,700,700i" rel="stylesheet">
    <!-- Vendor CSS Files -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    {% block css %}{% endblock%}
    <!-- =======================================================
    * Template Name: DWLL
    * Author: Jimbuho
    ======================================================== -->
</head>
<body>
    {% block menu %}
    {% include "menu.html" %}
    {% endblock %}
    {% block messages %}
    {% include "messages.html" %}
    {% endblock %}
    {% block header %}{% endblock %}
    {% block body %}{% endblock %}
    {% block footer %}
    {% include "footer.html" %}
    {% endblock %}  
</body>