"""

Module {{app_name}} Tests

Run tests with this command:
./manage.py test

"""
from django.test import TestCase

class Test{{app_name|title}}(TestCase):

    @classmethod
    def setUpTestData(cls):
        # Set up non-modified objects used by all test methods, by sample:
        # Author.objects.create(first_name='Big', last_name='Bob')
        pass

    def test_something(self):
        # Sample of a test
        # author = Author.objects.get(id=1)
        # self.assertEqual(author.first_name, 'Big')
        self.assertTrue(True)