{% extends 'base.html' %}
{% load i18n %}
{% load dwll %}
{% block title %}{% display_message 'bar.logout.title' 'Salir' %}{% endblock %}
{% block body %}
<section class="py-5">t
    <div class="container my-5">
        <div class="row justify-content-center">
            <div class="col-lg-6">
                <h2>{% display_message 'logout.title' 'Salir del sistema?' %}</h2>
                <form class="container-fluid text-center" id="logout_form" method="post" action="{% url 'account_logout' %}">
                    {% csrf_token %}
                    {% if redirect_field_value %}
                    <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}"/>
                    {% endif %}
                    <div class="form-group row">
                        <div class="col-sm-10"> 
                            <button  class="btn btn-primary" type="submit"> 
                                {% display_message 'logout.do' 'Salir' %}</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</section>
{% endblock %}