{% load i18n %}
{% load dwll %}
<header class="py-5 bg-image-full" style="background-image: url('https://source.unsplash.com/wfh8dDlNFOk/1600x900');">
    <div class="text-center my-5"><img class="img-fluid rounded-circle mb-4" src="https://dummyimage.com/150x150/6c757d/dee2e6.jpg" alt="...">
      <h1 class="text-white fs-3 fw-bolder">{% display_message 'home.header.title' 'Tu Página Aquí' %}</h1>
      <p class="text-white-50 mb-0">{% display_message 'home.header.subtitle' 'Imágenes tamaño completo' %}</p>
    </div>
</header>