"""My app description"""
VERSION = (1, 0, 0)
__version__ = '.'.join([str(i) for i in VERSION])
__author__ = 'Diego Gonzalez (jimuisrael)'
__email__ = 'dgonzalez.jim@gmail.com'
__url__ = 'https://github.com/jimuisrael/dwll'
__license__ = 'BSD'
__keywords__ = ['django acelerator', 'fast login', 'messages', 'configuration', 'rehuse']